# ------------------------------------------------------------------------------

# CIS - Community Innovation Survey, wave 4 - Data without Boundaries
# 
# This setup file converts the raw PORTUGAL data from CSV to an R object
# Checked for the July 2013 release of the CIS, as provided by Eurostat

# Version 2 of the file, January 2015
# Tested with R version 3.1.2 (2014-10-31) -- "Pumpkin Helmet"

# University of Bucharest, Romanian Social Data Archive
# Adrian Dusa
# http://www.roda.ro
# Contact: dusa.adrian@unibuc.ro
# 
# ------------------------------------------------------------------------------





# ------------------------------------------------------------------------------

# --- CONFIGURATION SECTION - START ---


# The following command should contain the complete path and
# name of the .csv file to be read (e.g. "C:/CIS 4/CSV/PT.csv")
# Change CSV_DATA_PATH to your filename, below:

csvpath <- "CSV_DATA_PATH"


# The following command should contain the complete path and
# name of the .Rdata file to be saved (e.g. "C:/CIS 4/R/PT.Rdata")
# Change RDATA_PATH to your filename, below:

rdatapath <- "RDATA_PATH"


# --- CONFIGURATION SECTION -  END  ---

# ------------------------------------------------------------------------------



# There should be nothing to change below this line
# ------------------------------------------------------------------------------



# --- Read the raw data ---

rdatafile <- read.csv(csvpath, sep = ",")

names(rdatafile) <- toupper(names(rdatafile))    # all variable names to upper case


# ------------------------------------------------------------------------------



# --- Recode string variables which have labels, to numeric variables ---

NACE_PRO <- rdatafile[ , "NACE_PRO"]
tempvar <- rep(NA, length(NACE_PRO))

tempvar[NACE_PRO == "C"] <- 1
tempvar[NACE_PRO == "DA"] <- 2
tempvar[NACE_PRO == "DB"] <- 3
tempvar[NACE_PRO == "DC"] <- 4
tempvar[NACE_PRO == "20_21"] <- 5
tempvar[NACE_PRO == "22"] <- 6
tempvar[NACE_PRO == "DF_DG"] <- 7
tempvar[NACE_PRO == "DH"] <- 8
tempvar[NACE_PRO == "DI"] <- 9
tempvar[NACE_PRO == "27"] <- 10
tempvar[NACE_PRO == "28"] <- 11
tempvar[NACE_PRO == "DK"] <- 12
tempvar[NACE_PRO == "DL"] <- 13
tempvar[NACE_PRO == "DM"] <- 14
tempvar[NACE_PRO == "DN"] <- 15
tempvar[NACE_PRO == "E"] <- 16
tempvar[NACE_PRO == "F"] <- 17
tempvar[NACE_PRO == "50"] <- 18
tempvar[NACE_PRO == "51"] <- 19
tempvar[NACE_PRO == "52"] <- 20
tempvar[NACE_PRO == "55"] <- 21
tempvar[NACE_PRO == "60_61_62"] <- 22
tempvar[NACE_PRO == "63"] <- 23
tempvar[NACE_PRO == "64"] <- 24
tempvar[NACE_PRO == "J"] <- 25
tempvar[NACE_PRO == "70"] <- 26
tempvar[NACE_PRO == "71"] <- 27
tempvar[NACE_PRO == "72"] <- 28
tempvar[NACE_PRO == "73_74"] <- 29

rdatafile[ , "NACE_PRO"] <- tempvar

PMOS <- rdatafile[ , "PMOS"]
tempvar <- rep(NA, length(PMOS))

tempvar[PMOS == "A"] <- 1
tempvar[PMOS == "B"] <- 2
tempvar[PMOS == "C"] <- 3
tempvar[PMOS == "D"] <- 4
tempvar[PMOS == "E"] <- 5
tempvar[PMOS == "F"] <- 6
tempvar[PMOS == "G"] <- 7

rdatafile[ , "PMOS"] <- tempvar


# ------------------------------------------------------------------------------



# --- Set the variable labels attribute --- 

attr(rdatafile, "variable labels") <- list(
"COUNTRY"  = "Country",
"GP"       = "Enterprise part of a group",
"ID"       = "Name of enterprise",
"NACE_PRO" = "Main activity",
"RRDINXM"  = "Expenditure in intramural R&D",
"RRDEXXM"  = "Expenditure in extramural R&D",
"RMACXM"   = "Expenditure in acquisition of machinery",
"ROEKXM"   = "Expenditure in other external knowledge",
"RTOT_MSK" = "Total for four expenditure categories",
"TURN02M"  = "Total turnover in 2002",
"TURN04M"  = "Total turnover in 2004",
"SIZE02"   = "Total number of employees in 2002",
"SIZE04"   = "Total number of employees in 2004",
"C_HO"     = "Country of head office",
"MARLOC"   = "Local/regional market",
"MARNAT"   = "National I market",
"MAREUR"   = "Other EU/EFTA/CC market",
"MAROTH"   = "All other countries",
"INPDGD"   = "Introduced onto the market a new or significantly improved good",
"INPDSV"   = "Introduced onto the market a new or significantly improved service",
"INPDTW"   = "Who mainly developed these products",
"NEWMKT"   = "Did the enterprise introduce a product new to the market",
"TURNMAR"  = "% of turnover in new or improved products introduced during 2002-2004 that were new to the market",
"TURNIN"   = "% of turnover in unchanged or marginally modified products during  2002-2004 that were new to the firm",
"TURNUNG"  = "% of turnover in unchanged or marginally modified products during 2002-2004",
"INPSPD"   = "Introduced onto the market a new or significantly improved method of production",
"INPSLG"   = "Introduced onto the market a new or significantly improved logistic, delivery or distribution system",
"INPSSU"   = "Introduced onto the market a new or significantly improved supporting activities",
"INPCSW"   = "Who mainly developed these processes",
"INONAB"   = "Enterprise with ongoing or abandoned innovation activities",
"RRDIN"    = "Engagement in intramural R&D",
"RDENG"    = "Type of engagement in R&D",
"RRDEX"    = "Engagement in extramural R&D",
"RMAC"     = "Engagement in acquisition of machinery",
"ROEK"     = "Engagement in other external knowledge",
"RTR"      = "Engagement in training",
"RMAR"     = "Engagement in market introduction of innovation",
"RPRE"     = "Engagement in other preparation",
"FUNLOC"   = "Public funding from local ro regional authorities",
"FUNGMT"   = "Public funding from central government",
"FUNEU"    = "Public funding from the EU",
"FUNRTD"   = "Funding from EU's 5th of 6th RTD",
"SENTG"    = "Sources from within the enterprise or enterprise group",
"SSUP"     = "Sources from Suppliers of equipment, materials, etc",
"SCLI"     = "Sources from Clients or customers",
"SCOM"     = "Sources from Competitors and other enterprises of same industry",
"SINS"     = "Sources from consultants, commercial labs or private R&D institutes",
"SUNI"     = "Sources from Universities or other higher education institutes",
"SGMT"     = "Sources from Government or public research institutes",
"SCON"     = "Sources from professional conferences, trade fairs, meetings",
"SJOU"     = "Sources from Scientific journals, trade/scientific publications",
"SPRO"     = "Sources from Professional and industry associations",
"CO"       = "Cooperation arrangements on innovation activities",
"CO11"     = "Other enterprises within enterprise group:National",
"CO12"     = "Other enterprises within enterprise group:EU/EFTA/EU-CC",
"CO13"     = "Other enterprises within enterprise group:US",
"CO14"     = "Other enterprises within enterprise group:Other countries",
"CO21"     = "Suppliers of equipment, etc:National",
"CO22"     = "Suppliers of equipment, etc:EU/EFTA/EU-CC",
"CO23"     = "Suppliers of equipment, etc:US",
"CO24"     = "Suppliers of equipment, etc:Other countries",
"CO31"     = "Clients or customers:National",
"CO32"     = "Clients or customers:EU/EFTA/EU-CC",
"CO33"     = "Clients or customers:US",
"CO34"     = "Clients or customers:Other countries",
"CO41"     = "Competitors or other firms ...:National",
"CO42"     = "Competitors or other firms ...:EU/EFTA/EU-CC",
"CO43"     = "Competitors or other firms ...:US",
"CO44"     = "Competitors or other firms ...:Other countries",
"CO51"     = "Consultants, commercial labs, private R&D institutes:National",
"CO52"     = "Consultants, commercial labs, private R&D institutes:EU/EFTA/EU-CC",
"CO53"     = "Consultants, commercial labs, private R&D institutes:US",
"CO54"     = "Consultants, commercial labs, private R&D institutes:Other countries",
"CO61"     = "Universities or other ...:National",
"CO62"     = "Universities or other ...:EU/EFTA/EU-CC",
"CO63"     = "Universities or other ...:US",
"CO64"     = "Universities or other ...:Other countries",
"CO71"     = "Government or public research institutes:National",
"CO72"     = "Government or public research institutes:EU/EFTA/EU-CC",
"CO73"     = "Government or public research institutes:US",
"CO74"     = "Government or public research institutes:Other countries",
"PMOS"     = "Most important co-operation partner",
"ERANGE"   = "Increased range of goods or services",
"EMAR"     = "Increased market or market share",
"EQUA"     = "Improved quality in goods or services",
"EFLEX"    = "Improved production flexibility",
"ECAP"     = "Increased production capacity",
"ELBR"     = "Reduced labour costs per produced unit",
"EMAT"     = "Reduced materials and energy per produced unit",
"EENV"     = "Reduced environmental impact or health and safety aspects",
"ESTD"     = "Met regulations or standards",
"HCON"     = "Innovation activity abandoned at concept stage",
"HBEG"     = "Innovation activity abandoned after the activity/project begun",
"HDLAY"    = "Innovation activity seriously delayed",
"HFENT"    = "Hampering factor: Lack of funds within enterprises or ent. group",
"HFOUT"    = "Hampering factor : Lack of outside funds",
"HCOS"     = "Hampering factor : Innovation costs too high",
"HPER"     = "Hampering factor : Lack of qualified personnel",
"HTEC"     = "Hampering factor : Lack of information on technology",
"HINF"     = "Hampering factor : Lack of information on markets",
"HPAR"     = "Hampering factor : Difficulty in finding co-operation partners",
"HDOM"     = "Hampering factor : Market dominated by established enterprises",
"HDEM"     = "Hampering factor: Uncertain demand for innovative goods/services",
"HPRIOR"   = "No innovation activity due to prior innovations",
"HMAR"     = "No innovation activity due to no demand for innovations",
"PROPAT"   = "Applied for a patent",
"PRODSG"   = "Registered an industrial design",
"PROTM"    = "Register a trademark",
"PROCP"    = "Claimed copyright",
"ORGSYS"   = "Introduce improved knowledge management system",
"ORGSTR"   = "Introduce change to work organisation",
"ORGREL"   = "Introduce a change in relations with other firms...",
"MKTDES"   = "Introduce significant design/packaging changes",
"MKTMET"   = "Introduce significantly changed sales/distribution methods",
"EFORED"   = "Reduced time to respond to customers needs",
"EFORQU"   = "Improved quality of goods/services",
"EFORCO"   = "Reduced costs per unit output",
"EFORSA"   = "Improved employee satisfaction",
"WEIGHT"   = "Weighting factors")


# ------------------------------------------------------------------------------



# --- Set the value labels attribute --- 

attr(rdatafile, "value labels") <- vector(mode="list", length=106)

attr(rdatafile, "value labels")[1:64] <- list(c(
    "No" = 0,
    "Yes" = 1
))

names(attr(rdatafile, "value labels"))[1:64] <- c(
    "GP", "MARLOC", "MARNAT", "MAREUR", "MAROTH", "INPDGD", "INPDSV", "NEWMKT", "INPSPD",
    "INPSLG", "INPSSU", "INONAB", "RRDIN", "RRDEX", "RMAC", "ROEK", "RTR", "RMAR", "RPRE",
    "FUNLOC", "FUNGMT", "FUNEU", "FUNRTD", "CO", "CO11", "CO12", "CO13", "CO14", "CO21",
    "CO22", "CO23", "CO24", "CO31", "CO32", "CO33", "CO34", "CO41", "CO42", "CO43", "CO44",
    "CO51", "CO52", "CO53", "CO54", "CO61", "CO62", "CO63", "CO64", "CO71", "CO72", "CO73",
    "CO74", "HCON", "HBEG", "HDLAY", "PROPAT", "PRODSG", "PROTM", "PROCP", "ORGSYS",
    "ORGSTR", "ORGREL", "MKTDES", "MKTMET"
)

attr(rdatafile, "value labels")[65] <- list(c(
    "Mining and quarrying" = 1,
    "Manufacture of food products, beverages and tobacco" = 2,
    "Manufacture of textiles and textile products" = 3,
    "Manufacture of leather and leather products" = 4,
    "Manufacture of wood and wood products; manufacture of pulp, paper and paper products" = 5,
    "Publishing, printing and reproduction of recorded media" = 6,
    "Manufacture of coke, refined petroleum products and nuclear fuel, of chemicals, chemical products and man-made fibres" = 7,
    "Manufacture of rubber and plastic products" = 8,
    "Manufacture of other non-metallic mineral products" = 9,
    "Manufacture of basic metals" = 10,
    "Manufacture of fabricated metal products, except machinery and equipment" = 11,
    "Manufacture of machinery and equipment n.e.c." = 12,
    "Manufacture of electrical and optical equipment" = 13,
    "Manufacture of transport equipment" = 14,
    "Manufacture of furniture, manufacturing n.e.c., Recycling" = 15,
    "Electricity, gas, steam and hot water supply" = 16,
    "Construction" = 17,
    "Sale, maintenance and repair of motor vehicles and motorcycles, retail sale of automotive fuel" = 18,
    "Wholesale trade and commission trade, except of motor vehicles and motorcycles" = 19,
    "Retail trade, except of motor vehicles and motorcycles, repair of personal and household goods" = 20,
    "Hotels and restaurants" = 21,
    "Land transport, transport via pipelines, water transport, air transport" = 22,
    "Supporting and auxiliary transport activities, activities of travel agencies" = 23,
    "Post and telecommunications" = 24,
    "Financial intermediation" = 25,
    "Real estate activities" = 26,
    "Renting of machinery and equipment without operator and of personal and household goods" = 27,
    "Computer and related activities" = 28,
    "Research and development; other business activities" = 29
))

names(attr(rdatafile, "value labels"))[65] <- "NACE_PRO"

attr(rdatafile, "value labels")[66:67] <- list(c(
    "Small (<50)" = 0,
    "Medium (50-249)" = 1,
    "Large (>=250)" = 2
))

names(attr(rdatafile, "value labels"))[66:67] <- c(
    "SIZE02", "SIZE04"
)

attr(rdatafile, "value labels")[68] <- list(c(
    "No answer" = 0,
    "Home country" = 1,
    "EU, EFTA, CC" = 2,
    "rest of the world" = 3
))

names(attr(rdatafile, "value labels"))[68] <- "C_HO"

attr(rdatafile, "value labels")[69:70] <- list(c(
    "Mainly by the enterprise or enterprise group" = 1,
    "In cooperation with other enterprises or institutions" = 2,
    "Mainly other enterprises or institutions" = 3
))

names(attr(rdatafile, "value labels"))[69:70] <- c(
    "INPDTW", "INPCSW"
)

attr(rdatafile, "value labels")[71] <- list(c(
    "Continuously" = 1,
    "Occasionally" = 2
))

names(attr(rdatafile, "value labels"))[71] <- "RDENG"

attr(rdatafile, "value labels")[72:81] <- list(c(
    "Not used" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
))

names(attr(rdatafile, "value labels"))[72:81] <- c(
    "SENTG", "SSUP", "SCLI", "SCOM", "SINS", "SUNI", "SGMT", "SCON", "SJOU", "SPRO"
)

attr(rdatafile, "value labels")[82] <- list(c(
    "Other enterprises within enterprise group" = 1,
    "Suppliers of equipment, etc" = 2,
    "Clients or customers" = 3,
    "Competitors or other firms" = 4,
    "Consultants, commercial labs, private R&D institutes" = 5,
    "Universities or other ..." = 6,
    "Government or public research institutes" = 7
))

names(attr(rdatafile, "value labels"))[82] <- "PMOS"

attr(rdatafile, "value labels")[83:91] <- list(c(
    "Not relevant" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
))

names(attr(rdatafile, "value labels"))[83:91] <- c(
    "ERANGE", "EMAR", "EQUA", "EFLEX", "ECAP", "ELBR", "EMAT", "EENV", "ESTD"
)

attr(rdatafile, "value labels")[92:106] <- list(c(
    "Not experienced" = 0,
    "Low" = 1,
    "Med" = 2,
    "High" = 3
))

names(attr(rdatafile, "value labels"))[92:106] <- c(
    "HFENT", "HFOUT", "HCOS", "HPER", "HTEC", "HINF", "HPAR", "HDOM", "HDEM", "HPRIOR",
    "HMAR", "EFORED", "EFORQU", "EFORCO", "EFORSA"
)


# ------------------------------------------------------------------------------



# --- Set the missing values attribute --- 

# only if the uniqueid variable really exists,
# and it has no duplicate or missing values

if ("ID" %in% names(rdatafile)) {
    if (!any(duplicated(rdatafile[, "ID"]))) {

        attr(rdatafile, "unique id") <- "ID"

        # C_HO
        attr(rdatafile, "missing types")$C_HO[["No answer"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$C_HO == 0])
        )

        rdatafile$C_HO[rdatafile$C_HO == 0] <- NA

        # SENTG
        attr(rdatafile, "missing types")$SENTG[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SENTG == 0])
        )

        rdatafile$SENTG[rdatafile$SENTG == 0] <- NA

        # SSUP
        attr(rdatafile, "missing types")$SSUP[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SSUP == 0])
        )

        rdatafile$SSUP[rdatafile$SSUP == 0] <- NA

        # SCLI
        attr(rdatafile, "missing types")$SCLI[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SCLI == 0])
        )

        rdatafile$SCLI[rdatafile$SCLI == 0] <- NA

        # SCOM
        attr(rdatafile, "missing types")$SCOM[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SCOM == 0])
        )

        rdatafile$SCOM[rdatafile$SCOM == 0] <- NA

        # SINS
        attr(rdatafile, "missing types")$SINS[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SINS == 0])
        )

        rdatafile$SINS[rdatafile$SINS == 0] <- NA

        # SUNI
        attr(rdatafile, "missing types")$SUNI[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SUNI == 0])
        )

        rdatafile$SUNI[rdatafile$SUNI == 0] <- NA

        # SGMT
        attr(rdatafile, "missing types")$SGMT[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SGMT == 0])
        )

        rdatafile$SGMT[rdatafile$SGMT == 0] <- NA

        # SCON
        attr(rdatafile, "missing types")$SCON[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SCON == 0])
        )

        rdatafile$SCON[rdatafile$SCON == 0] <- NA

        # SJOU
        attr(rdatafile, "missing types")$SJOU[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SJOU == 0])
        )

        rdatafile$SJOU[rdatafile$SJOU == 0] <- NA

        # SPRO
        attr(rdatafile, "missing types")$SPRO[["Not used"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$SPRO == 0])
        )

        rdatafile$SPRO[rdatafile$SPRO == 0] <- NA

        # ERANGE
        attr(rdatafile, "missing types")$ERANGE[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$ERANGE == 0])
        )

        rdatafile$ERANGE[rdatafile$ERANGE == 0] <- NA

        # EMAR
        attr(rdatafile, "missing types")$EMAR[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EMAR == 0])
        )

        rdatafile$EMAR[rdatafile$EMAR == 0] <- NA

        # EQUA
        attr(rdatafile, "missing types")$EQUA[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EQUA == 0])
        )

        rdatafile$EQUA[rdatafile$EQUA == 0] <- NA

        # EFLEX
        attr(rdatafile, "missing types")$EFLEX[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EFLEX == 0])
        )

        rdatafile$EFLEX[rdatafile$EFLEX == 0] <- NA

        # ECAP
        attr(rdatafile, "missing types")$ECAP[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$ECAP == 0])
        )

        rdatafile$ECAP[rdatafile$ECAP == 0] <- NA

        # ELBR
        attr(rdatafile, "missing types")$ELBR[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$ELBR == 0])
        )

        rdatafile$ELBR[rdatafile$ELBR == 0] <- NA

        # EMAT
        attr(rdatafile, "missing types")$EMAT[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EMAT == 0])
        )

        rdatafile$EMAT[rdatafile$EMAT == 0] <- NA

        # EENV
        attr(rdatafile, "missing types")$EENV[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EENV == 0])
        )

        rdatafile$EENV[rdatafile$EENV == 0] <- NA

        # ESTD
        attr(rdatafile, "missing types")$ESTD[["Not relevant"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$ESTD == 0])
        )

        rdatafile$ESTD[rdatafile$ESTD == 0] <- NA

        # HFENT
        attr(rdatafile, "missing types")$HFENT[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HFENT == 0])
        )

        rdatafile$HFENT[rdatafile$HFENT == 0] <- NA

        # HFOUT
        attr(rdatafile, "missing types")$HFOUT[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HFOUT == 0])
        )

        rdatafile$HFOUT[rdatafile$HFOUT == 0] <- NA

        # HCOS
        attr(rdatafile, "missing types")$HCOS[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HCOS == 0])
        )

        rdatafile$HCOS[rdatafile$HCOS == 0] <- NA

        # HPER
        attr(rdatafile, "missing types")$HPER[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HPER == 0])
        )

        rdatafile$HPER[rdatafile$HPER == 0] <- NA

        # HTEC
        attr(rdatafile, "missing types")$HTEC[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HTEC == 0])
        )

        rdatafile$HTEC[rdatafile$HTEC == 0] <- NA

        # HINF
        attr(rdatafile, "missing types")$HINF[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HINF == 0])
        )

        rdatafile$HINF[rdatafile$HINF == 0] <- NA

        # HPAR
        attr(rdatafile, "missing types")$HPAR[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HPAR == 0])
        )

        rdatafile$HPAR[rdatafile$HPAR == 0] <- NA

        # HDOM
        attr(rdatafile, "missing types")$HDOM[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HDOM == 0])
        )

        rdatafile$HDOM[rdatafile$HDOM == 0] <- NA

        # HDEM
        attr(rdatafile, "missing types")$HDEM[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HDEM == 0])
        )

        rdatafile$HDEM[rdatafile$HDEM == 0] <- NA

        # HPRIOR
        attr(rdatafile, "missing types")$HPRIOR[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HPRIOR == 0])
        )

        rdatafile$HPRIOR[rdatafile$HPRIOR == 0] <- NA

        # HMAR
        attr(rdatafile, "missing types")$HMAR[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$HMAR == 0])
        )

        rdatafile$HMAR[rdatafile$HMAR == 0] <- NA

        # EFORED
        attr(rdatafile, "missing types")$EFORED[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EFORED == 0])
        )

        rdatafile$EFORED[rdatafile$EFORED == 0] <- NA

        # EFORQU
        attr(rdatafile, "missing types")$EFORQU[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EFORQU == 0])
        )

        rdatafile$EFORQU[rdatafile$EFORQU == 0] <- NA

        # EFORCO
        attr(rdatafile, "missing types")$EFORCO[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EFORCO == 0])
        )

        rdatafile$EFORCO[rdatafile$EFORCO == 0] <- NA

        # EFORSA
        attr(rdatafile, "missing types")$EFORSA[["Not experienced"]] <- list(
        values = 0,
        cases = sort(rdatafile$ID[rdatafile$EFORSA == 0])
        )

        rdatafile$EFORSA[rdatafile$EFORSA == 0] <- NA

    }
}



# ------------------------------------------------------------------------------



# --- Save the R data file --- 

rfilename <- unlist(strsplit(basename(rdatapath), split="\\."))[1]
rdatapath <- file.path(dirname(rdatapath), paste(rfilename, ".Rdata", sep=""))
assign(rfilename, rdatafile)
eval(parse(text = paste("save(", rfilename, ", file=rdatapath)", sep="")))


# ------------------------------------------------------------------------------



# --- Clean up the working space --- 

rm(rfilename, rdatafile, csvpath, rdatapath, tempvar, NACE_PRO, PMOS)


# ------------------------------------------------------------------------------



